==> react-bootstrap-design-0.5.0.tgz: package/src/components/watch/dials/Iris.js <==
import React, { Component } from 'react';

class Iris extends Component {
    constructor(props) {
        super(props);

        this.state = {
            fluteStyles: { }
        }
    }

    componentDidMount() {
        var dial = this.dial
            , dialDiameter = dial.clientWidth
            , fluteWidth = dialDiameter / this.props.fluteCount;

        this.setState({
            fluteStyles: {
                borderLeftWidth: fluteWidth,
                borderRightWidth: fluteWidth,
                borderBottomWidth: dialDiameter
            }
        });

        window.addEventListener("resize", this.setFlute.bind(this));
    }

    setFlute() {
        var dial = this.dial
            , dialDiameter = dial.clientWidth
            , fluteWidth = dialDiameter / this.props.fluteCount;

        this.setState({
            fluteStyles: {
                borderLeftWidth: fluteWidth,
                borderRightWidth: fluteWidth,
                borderBottomWidth: dialDiameter
            }
        });
    }

    render() {
        var fluteStyles = this.state.fluteStyles;
        var fluteCount = this.props.fluteCount;

        var flutes = [];
        var i;
        for (i = 0; i <= fluteCount; i++) {
            var degrees = (360/fluteCount) * i;

            var rotation = {
                top: null,
	            left: null,
                transform: 'rotate(' + degrees + 'deg)'
            }

            const combinedStyles = Object.assign({}, rotation, fluteStyles);
            
            var flute = <span key={i} className="iris" style={combinedStyles}></span>;
            flutes.push(flute);
        }

        return (
            <div ref={(dial) => { this.dial = dial; }}
                    style={{
                        height: '100%',
                        width: '100%',
                        boxSizing: 'border-box',
                        position: 'absolute',
                        top: 0,
                        left: 0
                    }}>
                 {flutes}
            </div>
        )
    }
};

export default Iris

==> react-bootstrap-design-0.6.0.tgz: package/src/components/watch/dials/Iris.js <==
import React, { Component } from 'react';

class Iris extends Component {
    constructor(props) {
        super(props);

        this.state = {
            fluteStyles: { }
        }
    }

    componentDidMount() {
        var dial = this.dial
            , dialDiameter = dial.clientWidth
            , fluteWidth = dialDiameter / this.props.fluteCount;

        this.setState({
            fluteStyles: {
                borderLeftWidth: fluteWidth,
                borderRightWidth: fluteWidth,
                borderBottomWidth: dialDiameter
            }
        });

        window.addEventListener("resize", this.setFlute.bind(this));
    }

    setFlute() {
        var dial = this.dial
            , dialDiameter = dial.clientWidth
            , fluteWidth = dialDiameter / this.props.fluteCount;

        this.setState({
            fluteStyles: {
                borderLeftWidth: fluteWidth,
                borderRightWidth: fluteWidth,
                borderBottomWidth: dialDiameter
            }
        });
    }

    render() {
        var fluteStyles = this.state.fluteStyles;
        var fluteCount = this.props.fluteCount;

        var flutes = [];
        var i;
        for (i = 0; i <= fluteCount; i++) {
            var degrees = (360/fluteCount) * i;

            var rotation = {
                top: null,
	            left: null,
                transform: 'rotate(' + degrees + 'deg)',

                content: '',
                position: 'absolute',
                width: '0',
                height: '0',
                display: 'block',
                borderStyle: 'solid',
                borderLeftColor: 'transparent',
                borderRightColor: 'transparent',
                borderBottomColor: 'rgba(0, 0, 0, 0.05)',
                borderTopWidth: '0',
                top: '0',
                left: '45%'
            }

            const combinedStyles = Object.assign({}, rotation, fluteStyles);
            
            var flute = <span key={i} className="iris" style={combinedStyles}></span>;
            flutes.push(flute);
        }

        return (
            <div ref={(dial) => { this.dial = dial; }}
                    style={{
                        height: '100%',
                        width: '100%',
                        boxSizing: 'border-box',
                        position: 'absolute',
                        top: 0,
                        left: 0
                    }}>
                 {flutes}
            </div>
        )
    }
};

export default Iris
